Unicode Ranges Font Bits Information — jkUnicode 1.6.1 documentation

# Unicode Ranges Font Bits Information

`jkUnicode.uniRangesBits.` `getNameForRangeBit`(b)

  Get the name for the bit b. The meanings of the bits are specified in the OpenType specification for the OS/2 table ulUnicodeRange[1..4] entries.

  Parameters

    b (int) – The bit (0-127).

`jkUnicode.uniRangesBits.` `getUnicodesForRangeBit`(b)

  Get a list of unicodes for the bit b. The meanings of the bits are specified in the OpenType specification for the OS/2 table ulUnicodeRange[1..4] entries.

  Parameters

    b (int) – The bit (0-127).